@@ -1443,7 +1443,7 @@ public class User {
      *
      */
     public String getImapServer() {
-        return imapServer;
+        return null == imapServer ? imapServerString : imapServer;
     }
 
     /**
@@ -2259,7 +2259,7 @@ public class User {
      *
      */
     public String getSmtpServer() {
-        return smtpServer;
+        return null == smtpServer ? smtpServerString : smtpServer;
     }
 
     /**
